const path = require("path");

module.exports = grunt => {
    grunt.initConfig({
        pkg: grunt.file.readJSON("package.json"),
        clean: {
            default: ["dist/"],
        },
        exec: {
            eleventy: "npx @11ty/eleventy",
        },
        focus: {
            dev: {
                include: ["json", "njk"],
            },
        },
        replace: {
            dev: {
                src: ["./dist/**/*.html", "./dist/**/*.js"],
                replacements: [
                    {
                        from: "%%VERSION_NUMBER%%",
                        to: "<%= pkg.version %>+" + new Date().toISOString().slice(0, 19).replace(/[-:T]/g, "")
                    }
                ],
                overwrite: true
            },
            deploy: {
                src: ["./dist/**/*.html", "./dist/**/*.js"],
                replacements: [
                    {
                        from: "%%VERSION_NUMBER%%",
                        to: "<%= pkg.version %>"
                    }
                ],
                overwrite: true
            },
        },
        watch: {
            json: {
                files: ["src/main/**/*.json"],
                tasks: ["exec:eleventy", "replace:dev"],
            },
            njk: {
                files: ["src/main/**/*.njk"],
                tasks: ["exec:eleventy", "replace:dev"],
            },
        },
    });

    grunt.loadNpmTasks("grunt-contrib-clean");
    grunt.loadNpmTasks("grunt-contrib-watch");
    grunt.loadNpmTasks("grunt-exec");
    grunt.loadNpmTasks("grunt-focus");
    grunt.loadNpmTasks("grunt-text-replace");

    grunt.registerTask("dev", [
        // Pre
        "clean",
        // Generate site
        "exec:eleventy",
        // Insert version number
        "replace:dev",
    ]);
    grunt.registerTask("dev:server", ["dev", "focus:dev"]);
    grunt.registerTask("deploy", [
        // Pre
        "clean",
        // Generate site
        "exec:eleventy",
        // Insert version number
        "replace:deploy",
    ]);

    grunt.registerTask("default", ["dev"]);
};
